pub trait WrappingFrom<T>: Sized {
    fn from_wrapping(_: T) -> Self;
}
Creates Self from T, possibly wrapping around in the process.

Required Methods

Performs the conversion, possibly losing data in the process.

Implementors