Enum anyint::error::ParseIntError
source · [−]pub enum ParseIntError {
Empty,
InvalidDigit,
OutOfRange(OutOfRangeIntError),
Unknown,
}Expand description
Enum to store the various types of errors that can cause parsing an integer to fail.
Variants
Empty
cannot parse integer from empty string
InvalidDigit
invalid digit found in string
OutOfRange(OutOfRangeIntError)
Value {0} was too large or small to store in the target type.
Unknown
Unknown parsing error, this should never happen.