Trait anyint::convert::WrappingFrom
source · [−]pub trait WrappingFrom<T>: Sized {
fn from_wrapping(_: T) -> Self;
}Expand description
Creates Self from T, possibly wrapping around in the process.
Required Methods
fn from_wrapping(_: T) -> Self
fn from_wrapping(_: T) -> Self
Performs the conversion, possibly losing data in the process.